/* $Workfile: OtxBrd.h $   $Revision: 16 $    $Modtime: 12/02/99 4:46p $  */
#ifndef OTX_BRD_H
#define OTX_BRD_H
/******************************************************************************

  @doc PublicHwApi OtxBrd

  Copyright (C) 1998, 1999 Odin TeleSystems Inc., All Rights Reserved

  OTX Generic Hardware Driver API

  @module
  OtxBrd | OTX Board Level Function Prototypes

  @contents2
  OtxBrd.h |

  @index func | OtxBrd

  @contents2
  OTX Board Level Functions - OtxBrdXXX() | Functions available for Board Level Operations

  @head3 OtxBrdXXX() Function Reference |

  @index func | OtxBrd

******************************************************************************/

#include "OtxType.h"
#include "OtxDef.h"

#include "OtxDataD.h"
#include "OtxBrdD.h"

#ifdef __cplusplus
extern "C" {
#endif


/******************************************************************************

  @func
    Set the clock mode and the clock source for the OTX Board

  @comm
    All the highways on the OTX NIC Adapter are clocked with the same 8 kHz
    master framing clock. The source of the frame clock is set with this
    function.

  @xref
    <t OtxBrdClockModeE>
    <nl><t OtxBrdClockSourceE>

******************************************************************************/
OTX_RESULT OtxBrdSetClocks(
  IN OTX_HANDLE       hBrdDevice,   // @parm Handle to Board device
  IN OtxBrdClockModeE    clkMode,   // @parm TSS Clock Mode (Master/Slave)
  IN OtxBrdClockSourceE  clkSource  // @parm Clock which the TSS uses to clock the highways
);


/******************************************************************************

  @func
    Set the PCM compression mode for the Codec

  @xref
    <t OtxDataFormatE>

******************************************************************************/
OTX_RESULT OtxBrdCodecSetLaw(
  IN OTX_HANDLE      hCodecDevice,   // @parm Handle to Codec device
  IN OtxDataFormatE  eLaw            // @parm U-law or A-law
);



/******************************************************************************

  @func
    Set a timeslot to a constant value on a highway

******************************************************************************/
OTX_RESULT OtxBrdTssConstByte(
  IN OTX_HANDLE  hHwDevice,
  IN OTX_UINT32  nHighWayOut,
  IN OTX_UINT32  nTimeSlotOut,
  IN OTX_UINT8   nConstValue
);


#ifdef __cplusplus
}  // extern "C"
#endif

/******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 1998, 1999


  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

******************************************************************************/
#endif  // OTX_BRD_H
